@@ -1,20 +1,16 @@
 package TAP::DOM;
-# git description: v0.10-16-gc984b3e
-
 BEGIN {
   $TAP::DOM::AUTHORITY = 'cpan:SCHWIGON';
 }
-{
-  $TAP::DOM::VERSION = '0.11';
-}
 # ABSTRACT: TAP::DOM - TAP as Document Object Model.
-
+$TAP::DOM::VERSION = '0.12';
 use 5.006;
 use strict;
 use warnings;
 
 use TAP::DOM::Entry;
 use TAP::DOM::Summary;
+use TAP::DOM::DocumentData;
 use TAP::DOM::Config;
 use TAP::Parser;
 use TAP::Parser::Aggregator;
@@ -35,6 +31,8 @@ our $IS_YAML      = 1024;
 our $HAS_SKIP     = 2048;
 our $HAS_TODO     = 4096;
 
+our $document_data_regex = qr/^#\s*Test-([^:]+)\s*:\s*(.*)$/;
+
 use parent 'Exporter';
 our @EXPORT_OK = qw( $IS_PLAN
                      $IS_OK
@@ -82,6 +80,7 @@ use Class::XSAccessor
                         parse_errors
                         summary
                         tapdom_config
+                        document_data
                      )];
 
 sub new {
@@ -94,6 +93,7 @@ sub new {
         my $version;
         my @pragmas;
         my $bailout;
+        my %document_data;
 
         my %IGNORE      = map { $_ => 1 } @{$args{ignore}};
         my $IGNORELINES = $args{ignorelines};
@@ -178,6 +178,13 @@ sub new {
                 }
                 $entry->{data}         = $result->data if $result->is_yaml && !$IGNORE{data};
 
+                if ($result->is_comment and $result->as_string =~ $document_data_regex)
+                {
+                        my ($key, $value) = ($1, $2);
+                        $key =~ s/^\s+//; # strip leading  whitespace
+                        $key =~ s/\s+$//; # strip trailing whitespace
+                        $document_data{$key} = $value;
+                }
 
                 # yaml and comments are taken as children of the line before
                 if ($result->is_yaml or $result->is_comment and @lines)
@@ -220,6 +227,8 @@ sub new {
           usebitsets  => $USEBITSETS,
          );
 
+        my $document_data = TAP::DOM::DocumentData->new(%document_data);
+
         my $tapdata = {
                        plan          => $plan,
                        lines         => \@lines,
@@ -236,6 +245,7 @@ sub new {
                        parse_errors  => [ $parser->parse_errors ],
                        summary       => $summary,
                        tapdom_config => $tapdom_config,
+                       document_data => $document_data,
                       };
         return bless $tapdata, $class;
 }
@@ -306,7 +316,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -679,6 +689,28 @@ And the constants can be imported into your namespace:
 
 =head2 tapdom_config
 
+=head2 document_data
+
+A document can contain comment lines which actually contain key/value
+data, like this:
+
+  # Test-vendor-id:  GenuineIntel
+  # Test-cpu-model:  Intel(R) Core(TM) i7-3667U CPU @ 2.00GHz
+  # Test-cpu-family: 6
+  # Test-flags.fpu:  1
+
+Those lines are converted into a hash by splitting it at the C<:>
+delimiter and stripping the C<# Test-> prefix. The resulting data
+structure looks like this:
+
+  # ... inside TAP::DOM ...
+  document_data => {
+                    'vendor-id' => 'GenuineIntel',
+                    'cpu-model' => #Intel(R) Core(TM) i7-3667U CPU @ 2.00GHz',
+                    'cpu-family' => 6,
+                    'flags.fpu' =>  1,
+                   },
+
 =head2 tests_planned
 
 =head2 tests_run
@@ -691,7 +723,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
