@@ -1,7 +1,9 @@
 package TAP::DOM::DocumentData;
-our $AUTHORITY = 'cpan:SCHWIGON';
-# ABSTRACT: Accessors for key/value document data
-$TAP::DOM::DocumentData::VERSION = '0.93.2';
+BEGIN {
+  $TAP::DOM::DocumentData::AUTHORITY = 'cpan:SCHWIGON';
+}
+# ABSTRACT: TAP::DOM::DocumentData - Accessors for key/value document data
+$TAP::DOM::DocumentData::VERSION = '0.12';
 use 5.006;
 use strict;
 use warnings;
@@ -31,7 +33,7 @@ __END__
 
 =head1 NAME
 
-TAP::DOM::DocumentData - Accessors for key/value document data
+TAP::DOM::DocumentData - TAP::DOM::DocumentData - Accessors for key/value document data
 
 =head1 DESCRIPTION
 
@@ -73,7 +75,7 @@ Steffen Schwigon <ss5@renormalist.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Steffen Schwigon.
+This software is copyright (c) 2015 by Steffen Schwigon.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
